cumulusci.tasks.metadata package
================================

Subpackages
-----------

.. toctree::

    cumulusci.tasks.metadata.tests

Submodules
----------

cumulusci.tasks.metadata.ee\_src module
---------------------------------------

.. automodule:: cumulusci.tasks.metadata.ee_src
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.tasks.metadata.managed\_src module
--------------------------------------------

.. automodule:: cumulusci.tasks.metadata.managed_src
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.tasks.metadata.modify module
--------------------------------------

.. automodule:: cumulusci.tasks.metadata.modify
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.tasks.metadata.package module
---------------------------------------

.. automodule:: cumulusci.tasks.metadata.package
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: cumulusci.tasks.metadata
    :members:
    :undoc-members:
    :show-inheritance:
